@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2015 by the Quassel Project                        *
+ *   Copyright (C) 2005-2018 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -97,7 +97,7 @@ bool Compressor::initStreams()
     _deflater = new z_stream;
     memset(_deflater, 0, sizeof(z_stream));
     if (Z_OK != deflateInit(_deflater, zlevel)) {
-        qWarning() << "Could not intialize the deflate stream!";
+        qWarning() << "Could not initialize the deflate stream!";
         return false;
     }
 
