@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2015 by the Quassel Project                        *
+ *   Copyright (C) 2005-2018 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -62,6 +62,17 @@ bool CoreApplicationInternal::init()
 }
 
 
+bool CoreApplicationInternal::reloadConfig()
+{
+    if (_coreCreated) {
+        // Currently, only reloading SSL certificates is supported
+        return Core::reloadCerts();
+    } else {
+        return false;
+    }
+}
+
+
 /*****************************************************************************/
 
 CoreApplication::CoreApplication(int &argc, char **argv)
@@ -94,3 +105,13 @@ bool CoreApplication::init()
     }
     return false;
 }
+
+
+bool CoreApplication::reloadConfig()
+{
+    if (_internal) {
+        return _internal->reloadConfig();
+    } else {
+        return false;
+    }
+}
