@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2015 by the Quassel Project                        *
+ *   Copyright (C) 2005-2018 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -27,6 +27,7 @@
 #include <QSslKey>
 #include <QTcpServer>
 #include <QLinkedList>
+#include <QFile>
 
 class SslServer : public QTcpServer
 {
@@ -42,6 +43,16 @@ public:
     virtual inline const QSslKey &key() const { return _key; }
     virtual inline bool isCertValid() const { return _isCertValid; }
 
+    /**
+     * Reloads SSL certificates used for connections
+     *
+     * If this command fails, it will try to maintain the most recent working certificate.  Error
+     * conditions are automatically written to the log.
+     *
+     * @return True if certificates reloaded successfully, otherwise false.
+     */
+    bool reloadCerts();
+
 protected:
 #if QT_VERSION >= 0x050000
     virtual void incomingConnection(qintptr socketDescriptor);
@@ -52,11 +63,26 @@ protected:
     virtual bool setCertificate(const QString &path, const QString &keyPath);
 
 private:
+    /**
+     * Loads SSL certificates used for connections
+     *
+     * If this command fails, it will try to maintain the most recent working certificate.  Will log
+     * specific failure points, but does not offer verbose guidance.
+     *
+     * @return True if certificates loaded successfully, otherwise false.
+     */
+    bool loadCerts();
+    QSslKey loadKey(QFile *keyFile);
+
     QLinkedList<QTcpSocket *> _pendingConnections;
     QSslCertificate _cert;
     QSslKey _key;
     QList<QSslCertificate> _ca;
     bool _isCertValid;
+
+    // Used when reloading certificates later
+    QString _sslCertPath; /// Path to the certificate file
+    QString _sslKeyPath;  /// Path to the private key file (may be in same file as above)
 };
 
 
