@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2015 by the Quassel Project                        *
+ *   Copyright (C) 2005-2018 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -34,6 +34,15 @@ public:
 
     bool init();
 
+    /**
+     * Requests a reload of relevant runtime configuration.
+     *
+     * @see Quassel::reloadConfig()
+     *
+     * @return True if configuration reload successful, otherwise false
+     */
+    bool reloadConfig();
+
 private slots:
     void startInternalCore();
 
