@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2015 by the Quassel Project                        *
+ *   Copyright (C) 2005-2018 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -130,7 +130,7 @@ void QtUiMessageProcessor::checkForHighlight(Message &msg)
         }
         foreach(QString nickname, nickList) {
             QRegExp nickRegExp("(^|\\W)" + QRegExp::escape(nickname) + "(\\W|$)", _nicksCaseSensitive ? Qt::CaseSensitive : Qt::CaseInsensitive);
-            if (nickRegExp.indexIn(msg.contents()) >= 0) {
+            if (nickRegExp.indexIn(stripFormatCodes(msg.contents())) >= 0) {
                 msg.setFlags(msg.flags() | Message::Highlight);
                 return;
             }
@@ -161,7 +161,7 @@ void QtUiMessageProcessor::checkForHighlight(Message &msg)
             else {
                 rx = QRegExp("(^|\\W)" + QRegExp::escape(rule.name) + "(\\W|$)", rule.caseSensitive ? Qt::CaseSensitive : Qt::CaseInsensitive);
             }
-            bool match = (rx.indexIn(msg.contents()) >= 0);
+            bool match = (rx.indexIn(stripFormatCodes(msg.contents())) >= 0);
             if (match) {
                 msg.setFlags(msg.flags() | Message::Highlight);
                 return;
