@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2015 by the Quassel Project                        *
+ *   Copyright (C) 2005-2018 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -31,6 +31,9 @@ class UiStyle;
 #ifdef Q_OS_WIN
 #  include <windows.h>
 #endif
+#ifdef Q_OS_MAC
+#include <Carbon/Carbon.h>
+#endif
 
 class GraphicalUi : public AbstractUi
 {
@@ -119,6 +122,9 @@ private:
 #ifdef Q_OS_WIN
     DWORD _dwTickCount;
 #endif
+#ifdef Q_OS_MAC
+    ProcessSerialNumber _procNum;
+#endif
 };
 
 
